@@ -7,7 +7,7 @@
 #include "activeconnection.h"
 #include "connection.h"
 
-#include <QtDBus>
+#include <QDBusConnection>
 
 ActiveConnection::ActiveConnection(QObject *parent)
     : QObject(parent)
@@ -44,7 +44,7 @@ bool ActiveConnection::default6() const
     return m_default6;
 }
 
-QList< QDBusObjectPath > ActiveConnection::devices() const
+QList<QDBusObjectPath> ActiveConnection::devices() const
 {
     return m_devices;
 }
